.. -*- mode: rst -*-

SNOBFIT - Stable Noisy Optimization by Branch and FIT
=====================================================

SnobFit is intended for optimizing on derivative-free, noisy, blackbox functions.
This modified version has preset defaults as intended for hybrid quantum-classical
algorithms run on Noisy Intermediate Scale Quantum (NISQ) computers.

This version of SNOBFIT was modified and redistributed with permission.

Copyright of original (v2.1):
   A. Neumaier, University of Vienna

Copyright of modifications:
   UC Regents, Berkeley

Official website:
   https://www.mat.univie.ac.at/~neum/software/snobfit/

Reference:
   W. Huyer and A. Neumaier, "Snobfit - Stable Noisy Optimization by Branch and Fit",
   ACM Trans. Math. Software 35 (2008), Article 9.
   https://www.mat.univie.ac.at/~neum/ms/snobfit.pdf
